from setuptools import setup

setup(
    name='helloKaraseva',
    version='0.1.0',
    description='Lab 2 Python package',
    url='https://github.com/Karaseva-kote',
    author='Karaseva',
    author_email='karaseva@niuitmo.ru',
    packages=['helloKaraseva'],
    install_requires=['numpy>=1.17.3'],
)